@@ -2402,9 +2402,12 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 	     break;
    
   	  case(LABEL): 
-	     if (level == 0 || TOLABEL(areagen)->pin == False ||
-			(TOLABEL(areagen)->justify & PINVISIBLE))
-             UDrawString(TOLABEL(areagen), curcolor, theinstance);
+	     if (level == 0 || TOLABEL(areagen)->pin == False)
+                UDrawString(TOLABEL(areagen), curcolor, theinstance);
+	     else if ((TOLABEL(areagen)->justify & PINVISIBLE) && areawin->pinpointon)
+                UDrawString(TOLABEL(areagen), curcolor, theinstance);
+	     else if (TOLABEL(areagen)->justify & PINVISIBLE)
+                UDrawStringNoX(TOLABEL(areagen), curcolor, theinstance);
 	     else if (level == 1 && TOLABEL(areagen)->pin &&
 			TOLABEL(areagen)->pin != INFO && areawin->pinpointon)
 		UDrawXDown(TOLABEL(areagen));
@@ -2576,9 +2579,9 @@ void TopDoLatex()
    tx = (int)(72 / psscale) - origin.x,
    ty = (int)(72 / psscale) - origin.y;
 
-   fprintf(f, "   \\scalebox{%g}{%\n", outscale);
+   fprintf(f, "   \\scalebox{%g}{\n", outscale);
    fprintf(f, "   \\normalsize\n");
-   fprintf(f, "   \\parbox{%gin}{%\n", (((float)width * psscale) / 72.0) / outscale);
+   fprintf(f, "   \\parbox{%gin}{\n", (((float)width * psscale) / 72.0) / outscale);
    fprintf(f, "   \\includegraphics[scale=%g]{%s%s}\\\\\n", 1.0 / outscale,
 			filename, extend);
    fprintf(f, "   %% translate x=%d y=%d scale %3.2f\n", tx, ty, psscale);
